from django.core.management.base import BaseCommand
from osinacore.models import Task, Milestone


class Command(BaseCommand):
    help = 'Assign milestone to tasks based on related userstory or fallback to latest project milestone.'

    def handle(self, *args, **kwargs):
        tasks = Task.objects.filter(milestone__isnull=True, project__isnull=False)

        updated_count = 0

        for task in tasks:
            assigned_milestone = None

            # First priority: use milestone from userstory
            if task.userstory and task.userstory.milestone:
                assigned_milestone = task.userstory.milestone

            # Fallback: latest milestone from the project
            elif task.project:
                assigned_milestone = Milestone.objects.filter(project=task.project).order_by('-end_date').first()

            # Assign and save if found
            if assigned_milestone:
                task.milestone = assigned_milestone
                task.save()
                updated_count += 1

        self.stdout.write(self.style.SUCCESS(f"Assigned milestones to {updated_count} tasks."))
